aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--gn/services/genenetwork1.scm (renamed from gn/services/genenetwork.scm)4
1 files changed, 2 insertions, 2 deletions
diff --git a/gn/services/genenetwork.scm b/gn/services/genenetwork1.scm
index 9f48ac6..4e29956 100644
--- a/gn/services/genenetwork.scm
+++ b/gn/services/genenetwork1.scm
@@ -1,4 +1,4 @@
-(define-module (gn services genenetwork))
+(define-module (gn services genenetwork1))
(use-modules (gnu)
(past packages python)
@@ -29,5 +29,5 @@
(package httpd22-with-mod-python)
(config GN1-httpd-config))))))
;; guix system container -L /path/to/guix-past/modules/ -L /path/to/guix-bioinformatics/ /path/to/guix-bioinformatics/gn/services/genenetwork.scm --network --expose=/gnshare/gn/web/genotypes
;; xdg-open http://localhost:8042
@@ -29,5 +29,5 @@
(package httpd22-with-mod-python)
(config GN1-httpd-config))))))
-;; guix system container -L /path/to/guix-past/modules/ -L /path/to/guix-bioinformatics/ /path/to/guix-bioinformatics/gn/services/genenetwork.scm --network --expose=/gnshare/gn/web/genotypes
+;; guix system container -L /path/to/guix-past/modules/ -L /path/to/guix-bioinformatics/ /path/to/guix-bioinformatics/gn/services/genenetwork1.scm --network --expose=/gnshare/gn/web/genotypes
;; xdg-open http://localhost:8042